@@ -6,9 +6,9 @@ Type annotations for machinelearning service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_machinelearning.literals import Algorithm
+    from mypy_boto3_machinelearning.literals import AlgorithmType
 
-    data: Algorithm = "sgd"
+    data: AlgorithmType = "sgd"
     ```
 """
 import sys
@@ -20,31 +20,31 @@ else:
 
 
 __all__ = (
-    "Algorithm",
+    "AlgorithmType",
     "BatchPredictionAvailableWaiterName",
-    "BatchPredictionFilterVariable",
+    "BatchPredictionFilterVariableType",
     "DataSourceAvailableWaiterName",
-    "DataSourceFilterVariable",
+    "DataSourceFilterVariableType",
     "DescribeBatchPredictionsPaginatorName",
     "DescribeDataSourcesPaginatorName",
     "DescribeEvaluationsPaginatorName",
     "DescribeMLModelsPaginatorName",
-    "DetailsAttributes",
-    "EntityStatus",
+    "DetailsAttributesType",
+    "EntityStatusType",
     "EvaluationAvailableWaiterName",
-    "EvaluationFilterVariable",
+    "EvaluationFilterVariableType",
     "MLModelAvailableWaiterName",
-    "MLModelFilterVariable",
-    "MLModelType",
-    "RealtimeEndpointStatus",
-    "SortOrder",
-    "TaggableResourceType",
+    "MLModelFilterVariableType",
+    "MLModelTypeType",
+    "RealtimeEndpointStatusType",
+    "SortOrderType",
+    "TaggableResourceTypeType",
 )
 
 
-Algorithm = Literal["sgd"]
+AlgorithmType = Literal["sgd"]
 BatchPredictionAvailableWaiterName = Literal["batch_prediction_available"]
-BatchPredictionFilterVariable = Literal[
+BatchPredictionFilterVariableType = Literal[
     "CreatedAt",
     "DataSourceId",
     "DataURI",
@@ -55,17 +55,17 @@ BatchPredictionFilterVariable = Literal[
     "Status",
 ]
 DataSourceAvailableWaiterName = Literal["data_source_available"]
-DataSourceFilterVariable = Literal[
+DataSourceFilterVariableType = Literal[
     "CreatedAt", "DataLocationS3", "IAMUser", "LastUpdatedAt", "Name", "Status"
 ]
 DescribeBatchPredictionsPaginatorName = Literal["describe_batch_predictions"]
 DescribeDataSourcesPaginatorName = Literal["describe_data_sources"]
 DescribeEvaluationsPaginatorName = Literal["describe_evaluations"]
 DescribeMLModelsPaginatorName = Literal["describe_ml_models"]
-DetailsAttributes = Literal["Algorithm", "PredictiveModelType"]
-EntityStatus = Literal["COMPLETED", "DELETED", "FAILED", "INPROGRESS", "PENDING"]
+DetailsAttributesType = Literal["Algorithm", "PredictiveModelType"]
+EntityStatusType = Literal["COMPLETED", "DELETED", "FAILED", "INPROGRESS", "PENDING"]
 EvaluationAvailableWaiterName = Literal["evaluation_available"]
-EvaluationFilterVariable = Literal[
+EvaluationFilterVariableType = Literal[
     "CreatedAt",
     "DataSourceId",
     "DataURI",
@@ -76,7 +76,7 @@ EvaluationFilterVariable = Literal[
     "Status",
 ]
 MLModelAvailableWaiterName = Literal["ml_model_available"]
-MLModelFilterVariable = Literal[
+MLModelFilterVariableType = Literal[
     "Algorithm",
     "CreatedAt",
     "IAMUser",
@@ -88,7 +88,7 @@ MLModelFilterVariable = Literal[
     "TrainingDataSourceId",
     "TrainingDataURI",
 ]
-MLModelType = Literal["BINARY", "MULTICLASS", "REGRESSION"]
-RealtimeEndpointStatus = Literal["FAILED", "NONE", "READY", "UPDATING"]
-SortOrder = Literal["asc", "dsc"]
-TaggableResourceType = Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"]
+MLModelTypeType = Literal["BINARY", "MULTICLASS", "REGRESSION"]
+RealtimeEndpointStatusType = Literal["FAILED", "NONE", "READY", "UPDATING"]
+SortOrderType = Literal["asc", "dsc"]
+TaggableResourceTypeType = Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"]
